@@ -4,6 +4,7 @@ from flake8_fine_pytest.watchers.base import BaseWatcher
 
 
 class SignatureComplexityWatcher(BaseWatcher):
+    config_option = 'allowed_test_arguments_count'
     error_template = (
         'FP004 {test_name} has too complex signature. '
         'Allowed count of arguments is {allowed_arguments}'
@@ -11,24 +12,16 @@ class SignatureComplexityWatcher(BaseWatcher):
 
     def run(self) -> None:
         self.allowed_test_arguments_count = self.options.allowed_test_arguments_count
-
-        if self._should_check():
-            self._validate_signature_arguments_count(self.tree)
-
-    def _should_check(self) -> bool:
-        return self._is_test_file(self.filename) and self.allowed_test_arguments_count is not None
+        self._validate_signature_arguments_count(self.tree)
 
     def _validate_signature_arguments_count(self, tree: ast.AST) -> None:
         for node in ast.walk(tree):
-            if self._is_properly_node(node) is False:
+            if self._should_check_node(node) is False:
                 continue
 
             if self._is_invalid_signature(node) is True:  # type: ignore
                 self._note_an_error(node)
 
-    def _is_properly_node(self, node: ast.AST) -> bool:
-        return isinstance(node, ast.FunctionDef) and node.name.startswith('test_')
-
     def _is_invalid_signature(self, ast_node: ast.FunctionDef) -> bool:
         signature_arguments = ast_node.args.args
 
